"""intro.py - a context for displaying a splash screen, slideshow,
movie, etc.

This file is part of Gummworld2.

Gummworld2 is free software: you can redistribute it and/or modify it
under the terms of the GNU Lesser General Public License as published
by the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Gummworld2 is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with Gummworld2.  If not, see <http://www.gnu.org/licenses/>.
"""

import random

import pygame

import gummworld2
from gummworld2 import State, Vec2d

import settings, mainmenu

class Intro(gummworld2.Engine):
    
    def __init__(self):
        gummworld2.Engine.__init__(self,
            resolution=settings.resolution,
            update_speed=60, frame_speed=140,
        )
        State.clock.use_wait = True
    
    def enter(self):
        self.screen.clear_color = pygame.Color('darkgreen')
        font_file = gummworld2.data.filepath('font', 'VeraBd.ttf')
        self.font = pygame.font.Font(font_file, 38)
        self.countdown = 10.99999  ## float, seconds
        self.text = ''
        self.text_rect = pygame.Rect(3, 3, 1, 1)
        self.update_text()
        self.dx = random.choice((-2,-2,-1,1,2,3))
        self.dy = random.choice((-3,-2,-1,1,2,3))
        self.old_pos = Vec2d(self.text_rect.topleft)
        self.old_dxy = Vec2d(self.dx, self.dy)
    
    def update(self, dt):
        self.countdown -= dt
        if int(self.countdown) <= 0:
            self.action_main_menu()
        
        self.update_text()
        text_rect = self.text_rect
        self.old_pos[:] = text_rect.topleft
        self.old_dxy[:] = self.dx, self.dy
        text_rect.x += self.dx
        text_rect.y += self.dy
        screen_rect = State.screen.rect
        if not screen_rect.contains(text_rect):
            if text_rect.x < 0 or text_rect.right >= screen_rect.right:
                self.dx *= -1
            if text_rect.y < 0 or text_rect.bottom >= screen_rect.bottom:
                self.dy *= -1
            self.text_rect.clamp_ip(screen_rect)
    
    def update_text(self):
        new_text = 'Intro (Wait {0:d} or Click)'.format(int(self.countdown))
        if new_text == self.text:
            return
        self.text = new_text
        self.text_img = self.font.render(new_text, True, pygame.Color('white'))
        self.text_rect.size = self.text_img.get_size()
    
    def draw(self, interp):
        State.screen.clear()
        x,y = self.old_pos + self.old_dxy * interp
        interp_pos = round(x), round(y)
        #print(interp_pos)
        State.screen.blit(self.text_img, interp_pos)
        State.screen.flip()
    
    def action_main_menu(self):
        self.pop()
        self.push(mainmenu.MainMenu())
    
    def on_mouse_button_down(self, pos, button):
        self.action_main_menu()
